@@ -1,6 +1,7 @@
 from enum import Enum
+from os import getcwd
 from os.path import exists 
-from requests import get 
+from requests import get
 
 from numpy import loadtxt
 
@@ -11,14 +12,15 @@ def download_file(url:str,path:str) -> None:
         return
     result = get(url)
     if result.ok:
-        with open(PATH,'w') as vector_file:
+        with open(path,'w') as vector_file:
             vector_file.write(result.text)
 
 PREPROCESSOR = PreprocessingPipeline()
 METAPHONES = "ABCEFHIJKLMNOPRSTUWXY0. "
 SIZE_METAPHONES = len(METAPHONES)
-PATH = "ffast/poincare/poincare.txt"
-download_file(url="https://raw.githubusercontent.com/mohammedterryjack/Joint-Intent-Slots/master/word_vectors/poincare.txt",path=PATH)
+HERE = getcwd()
+PATH = f"{HERE}/poincare.txt"
+download_file(path=PATH,url="https://raw.githubusercontent.com/mohammedterryjack/Joint-Intent-Slots/master/word_vectors/poincare.txt")
 raw_vocab = loadtxt(PATH,usecols=0,dtype=str)
 VOCABULARY = list(map(PREPROCESSOR.normalise,raw_vocab))
 VECTORS = loadtxt(PATH,usecols=range(1,101))
